#!/usr/local/bin/python
import json
import sys

from common import Constants
from pyspark.sql import SparkSession
from pyspark.sql.types import StringType
from rules import MD5
from sources import Sources, Sinks


def getColumns(x):
    sql_list = []
    sql_file_list = []
    list = [i for i in json.loads(x).get('col')]
    for i in range(0, len(list)):
        if json.loads(x).get('tm').get(list[i]) == "md5":
            sql_list.append(' md5('+list[i]+') as '+list[i]+", "+list[i]+' as t_'+list[i])
            sql_file_list.append(' md5('+list[i]+') as '+list[i])
        elif json.loads(x).get('tm').get(list[i]) == "rtl":
            sql_list.append(' rtl('+list[i]+') as '+list[i]+", "+list[i]+' as t_'+list[i])
            sql_file_list.append(' rtl('+list[i]+') as '+list[i])
        else:
            sql_list.append(' ' + list[i])
            sql_file_list.append(' ' + list[i])
    col = ""
    col_file = ""
    for i in sql_list:
        col += i + ','

    for i in sql_file_list:
        col_file += i + ','

    sql = "select " + col + " current_timestamp() as create_time from kino"
    sql_file = "select " + col_file[0:-1] + " from kino"
    print("---------------------->", sql)
    print("---------------------->", sql_file)
    return [sql, sql_file]

if __name__ == '__main__':
    # 拿到 列名 等
    record = Sources.getRecordByIdResultT1(sys.argv[1])
    col = json.loads(str(record)[2:-3]).get('col')
    sql_lists = getColumns(str(record)[2:-3])
    sql = sql_lists[0]
    sql_file = sql_lists[1]
    sink_method = json.loads(str(record)[2:-3]).get('sink_method')

    # spark 初始化
    spark = SparkSession.Builder().appName('sql').master('local').getOrCreate()

    spark.udf.register('md5', MD5.md5, StringType())
    print('=======>', sys.argv[2])

    df = Sources.readCsv(spark, sys.argv[2], col)

    t_table = df.createTempView('kino')
    sinkDF = spark.sql(sql)
    sinkFileDF = spark.sql(sql_file)
    sinkFileDF.show()

    if sink_method.lower() == 'hdfs':
        # TODO 落 HDFS
        Sinks.sinkHDFS(sinkDF=sinkFileDF,
                       path=Constants.HDFS_PATH,
                       delimiter=",",
                       format="csv",
                       mode=Constants.SAVE_MODE_OVERWRITE)
    elif sink_method.lower() == 'mysql':
        # TODO 落 MySQL
        Sinks.sinkMySql(sinkDF,
                        mode=Constants.SAVE_MODE_OVERWRITE,
                        driver=Constants.MY_MYSQL_DRIVER,
                        url=Constants.MY_MYSQL_URL,
                        user=Constants.MY_MYSQL_USER,
                        password=Constants.MY_MYSQL_PASSWORD,
                        table="test1")
    elif sink_method.lower() == 'ftp':
        print("落FTP")
    else:
        print("...")

    # TODO 修改状态, 数据校验(读取-写出 数据量)
    Sinks.updateMysqlStatus(i_status=1, i_readcount=df.count(), i_sinkcount=sinkDF.count(), i_id=1)

    # 关闭spark会话
    spark.stop()






